@@ -32,9 +32,7 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-"""Test fparser scripts
-
-"""
+"""Test fparser scripts"""
 
 # pylint: disable=too-few-public-methods
 
