@@ -52,15 +52,9 @@ def test_fparser_get_version(monkeypatch):
         """Broken routine with which to patch the `version` method."""
         raise fparser.PackageNotFoundError()
 
-    try:
-        from importlib import metadata
+    from importlib import metadata
 
-        monkeypatch.setattr(metadata, "version", _broken_version)
-    except ImportError:
-        # Use backport package for python <3.8
-        import importlib_metadata
-
-        monkeypatch.setattr(importlib_metadata, "version", _broken_version)
+    monkeypatch.setattr(metadata, "version", _broken_version)
     ver2 = fparser._get_version()
     assert isinstance(ver2, str)
     assert "." in ver2
@@ -88,6 +82,9 @@ def test_fparser_logging_handler(tmpdir, caplog):
         "Skipped bad character in input file. Error returned was 'ascii' "
         "codec can't decode byte "
     ) in caplog.text
-    # Can't check the actual value as some versions of Python3 return
-    # a different value to the one above.
-    assert "in position 1: ordinal not in range(128)." in caplog.text
+
+    assert (
+        "Skipped bad character in input file. Error returned was 'ascii' "
+        "codec can't decode byte 0xc3 in position 1: ordinal not in "
+        "range(128)." in caplog.text
+    )
