@@ -1,4 +1,4 @@
-# Modified work Copyright (c) 2017 Science and Technology Facilities Council
+# Modified work Copyright (c) 2017-2022 Science and Technology Facilities Council.
 # Original work Copyright (c) 1999-2008 Pearu Peterson
 
 # All rights reserved.
@@ -65,15 +65,18 @@
 import pytest
 from fparser import api
 
-@pytest.mark.xfail(reason="Fails in fparser1 as the reader now passes "
-                   "include onto the parser if the include is not found")
+
+@pytest.mark.xfail(
+    reason="Fails in fparser1 as the reader now passes "
+    "include onto the parser if the include is not found"
+)
 def test_reproduce_issue():
-    source_str = '''\
+    source_str = """\
       subroutine bndfp()
         include "events.ins"
       end
-'''
-    tree = api.parse(source_str, isfree=False, isstrict=False,
-                     ignore_comments=False)
-    assert str(tree).strip().split('\n')[1:]=='''
-    '''.strip().split('\n')[1:]
+"""
+    tree = api.parse(source_str, isfree=False, isstrict=False, ignore_comments=False)
+    expected = """
+    """
+    assert str(tree).strip().split("\n")[1:] == expected.strip().split("\n")[1:]
