@@ -32,10 +32,10 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-'''Test Fortran 2003 rule R427 : This file tests the support for a
+"""Test Fortran 2003 rule R427 : This file tests the support for a
 character literal constant.
 
-'''
+"""
 
 import pytest
 from fparser.two.Fortran2003 import Char_Literal_Constant
@@ -43,14 +43,13 @@ from fparser.two.utils import NoMatchError, InternalError
 
 
 def test_match_valid():
-    ''' Test that valid input is parsed correctly '''
+    """Test that valid input is parsed correctly"""
 
     # simple, single quotes
     obj = Char_Literal_Constant("'DO'")
     assert isinstance(obj, Char_Literal_Constant), repr(obj)
     assert str(obj) == "'DO'"
-    assert repr(obj).replace("u", "") == \
-        'Char_Literal_Constant("\'DO\'", None)'
+    assert repr(obj).replace("u", "") == "Char_Literal_Constant(\"'DO'\", None)"
 
     # simple, double quotes
     obj = Char_Literal_Constant('"DO"')
@@ -71,8 +70,7 @@ def test_match_valid():
     obj = Char_Literal_Constant("  '  D  O  '  ")
     assert isinstance(obj, Char_Literal_Constant), repr(obj)
     assert str(obj) == "'  D  O  '"
-    assert repr(obj).replace('u"', '"') == \
-        'Char_Literal_Constant("\'  D  O  \'", None)'
+    assert repr(obj).replace('u"', '"') == "Char_Literal_Constant(\"'  D  O  '\", None)"
 
     # Single quotes, empty string
     obj = Char_Literal_Constant("''")
@@ -89,15 +87,13 @@ def test_match_valid():
     obj = Char_Literal_Constant('KP_"DO"')
     assert isinstance(obj, Char_Literal_Constant), repr(obj)
     assert str(obj) == 'KP_"DO"'
-    assert repr(obj).replace("u'", "'") == \
-        'Char_Literal_Constant(\'"DO"\', \'KP\')'
+    assert repr(obj).replace("u'", "'") == "Char_Literal_Constant('\"DO\"', 'KP')"
 
     # include a kind parameter with spaces
     obj = Char_Literal_Constant('  KP  _  "  D  O  "  ')
     assert isinstance(obj, Char_Literal_Constant), repr(obj)
     assert str(obj) == 'KP_"  D  O  "'
-    assert repr(obj).replace("u'", "'") == \
-        'Char_Literal_Constant(\'"  D  O  "\', \'KP\')'
+    assert repr(obj).replace("u'", "'") == "Char_Literal_Constant('\"  D  O  \"', 'KP')"
 
     # additional characters
     obj = Char_Literal_Constant("'()!$%^&*_+=-01~@#;:/?.>,<|'")
@@ -106,32 +102,47 @@ def test_match_valid():
 
 
 def test_match_invalid():
-    ''' Test that invalid input raises an exception '''
+    """Test that invalid input raises an exception"""
 
     # test various invalid options
-    for example in [None, "", "  ", "A", "'A", "A'", "\"A", "A\"", "A'A'",
-                    "A 'A'", "'A'A", "'A' A", "_'A'", "$_'A'", "A A_'A'",
-                    "A_'A'A", "A_'A' A"]:
+    for example in [
+        None,
+        "",
+        "  ",
+        "A",
+        "'A",
+        "A'",
+        '"A',
+        'A"',
+        "A'A'",
+        "A 'A'",
+        "'A'A",
+        "'A' A",
+        "_'A'",
+        "$_'A'",
+        "A A_'A'",
+        "A_'A'A",
+        "A_'A' A",
+    ]:
         with pytest.raises(NoMatchError) as excinfo:
             _ = Char_Literal_Constant(example)
-        assert "Char_Literal_Constant: '{0}'".format(example) in \
-            str(excinfo.value)
+        assert "Char_Literal_Constant: '{0}'".format(example) in str(excinfo.value)
 
 
 def test_tostr_invalid1(monkeypatch):
-    ''' Test that an invalid number of items raises an exception '''
+    """Test that an invalid number of items raises an exception"""
 
     # test internal error in tostr() when the items list is not the
     # expected size
     obj = Char_Literal_Constant("'A'")
-    monkeypatch.setattr(obj, "items", ['A'])
+    monkeypatch.setattr(obj, "items", ["A"])
     with pytest.raises(InternalError) as excinfo:
         _ = str(obj)
     assert "tostr() has '1' items, but expecting 2" in str(excinfo.value)
 
 
 def test_tostr_invalid2(monkeypatch):
-    ''' Test that an empty items value raises an exception '''
+    """Test that an empty items value raises an exception"""
 
     # test internal error in tostr() when the items list index 0 has
     # no content
@@ -143,12 +154,12 @@ def test_tostr_invalid2(monkeypatch):
 
 
 def test_tostr_non_ascii():
-    ''' Check that the tostr() method works when the character string
-    contains non-ascii characters. '''
-    obj = Char_Literal_Constant(u"'for e1=1\xb0'")
+    """Check that the tostr() method works when the character string
+    contains non-ascii characters."""
+    obj = Char_Literal_Constant("'for e1=1\xb0'")
     out_str = str(obj)
     assert "for e1=1" in out_str
     # With a kind specifier...
-    obj = Char_Literal_Constant(u"ckind_'for e1=1\xb0'")
+    obj = Char_Literal_Constant("ckind_'for e1=1\xb0'")
     out_str = str(obj)
     assert "ckind_'for e1=" in out_str
