@@ -32,7 +32,7 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-'''Test Fortran 2003 rule R1101 : This file tests the support for a
+"""Test Fortran 2003 rule R1101 : This file tests the support for a
 main program with a program statement. It does not test the case where
 there is no program statement. That situation is covered by the
 Main_Program0 class. Tests for Main_Program0 are currently in
@@ -44,7 +44,7 @@ individual rules (e.g we do not need to worry about "end", "end
 program", "end program a" as these should be covered by the tests for
 End_Program_Unit
 
-'''
+"""
 
 import pytest
 from fparser.two.utils import FortranSyntaxError, NoMatchError
@@ -54,33 +54,37 @@ from fparser.two.symbol_table import SYMBOL_TABLES
 
 
 def test_valid(f2003_create):
-    '''
+    """
     Test that valid code is parsed correctly and associated symbol tables
     created.
 
-    '''
+    """
     # basic
     obj = Main_Program(get_reader("program a\nend"))
     assert isinstance(obj, Main_Program)
-    assert str(obj) == 'PROGRAM a\nEND'
-    assert repr(obj) == ("Main_Program(Program_Stmt('PROGRAM', Name('a')), "
-                         "End_Program_Stmt(None, None))")
+    assert str(obj) == "PROGRAM a\nEND"
+    assert repr(obj) == (
+        "Main_Program(Program_Stmt('PROGRAM', Name('a')), "
+        "End_Program_Stmt(None, None))"
+    )
 
     # name matching
     obj = Main_Program(get_reader("program a\nend program a"))
     assert isinstance(obj, Main_Program)
-    assert str(obj) == 'PROGRAM a\nEND PROGRAM a'
-    assert repr(obj) == ("Main_Program(Program_Stmt('PROGRAM', Name('a')), "
-                         "End_Program_Stmt('PROGRAM', Name('a')))")
+    assert str(obj) == "PROGRAM a\nEND PROGRAM a"
+    assert repr(obj) == (
+        "Main_Program(Program_Stmt('PROGRAM', Name('a')), "
+        "End_Program_Stmt('PROGRAM', Name('a')))"
+    )
 
     # mixed case name matching
     obj = Main_Program(get_reader("program a\nend program A"))
     assert isinstance(obj, Main_Program)
-    assert str(obj) == 'PROGRAM a\nEND PROGRAM A'
+    assert str(obj) == "PROGRAM a\nEND PROGRAM A"
 
     # specification-part
     obj = Main_Program(get_reader("program a\ninteger i\nend program a"))
-    assert str(obj) == 'PROGRAM a\n  INTEGER :: i\nEND PROGRAM a'
+    assert str(obj) == "PROGRAM a\n  INTEGER :: i\nEND PROGRAM a"
     table = SYMBOL_TABLES.lookup("a")
     assert table.lookup("i")
     # Clear existing symbol tables before next part of this test
@@ -88,40 +92,50 @@ def test_valid(f2003_create):
 
     # execution-part
     obj = Main_Program(get_reader("program a\ni=10\nend program a"))
-    assert str(obj) == 'PROGRAM a\n  i = 10\nEND PROGRAM a'
+    assert str(obj) == "PROGRAM a\n  i = 10\nEND PROGRAM a"
 
     # internal-subprogram-part
-    obj = Main_Program(get_reader("program a\ncontains\nsubroutine foo\n"
-                                  "end\nend program a"))
-    assert str(obj) == ("PROGRAM a\n  CONTAINS\n  SUBROUTINE foo\n"
-                        "  END\nEND PROGRAM a")
+    obj = Main_Program(
+        get_reader("program a\ncontains\nsubroutine foo\n" "end\nend program a")
+    )
+    assert str(obj) == (
+        "PROGRAM a\n  CONTAINS\n  SUBROUTINE foo\n" "  END\nEND PROGRAM a"
+    )
 
     # specification-part + execution-part
     obj = Main_Program(get_reader("program a\ninteger i\ni=10\nend program a"))
-    assert str(obj) == 'PROGRAM a\n  INTEGER :: i\n  i = 10\nEND PROGRAM a'
+    assert str(obj) == "PROGRAM a\n  INTEGER :: i\n  i = 10\nEND PROGRAM a"
     # Clear existing symbol tables before next part of this test
     SYMBOL_TABLES.clear()
 
     # execution-part + internal-subprogram-part
-    obj = Main_Program(get_reader("program a\ni=10\ncontains\nsubroutine foo\n"
-                                  "end\nend program a"))
-    assert str(obj) == ("PROGRAM a\n  i = 10\n  CONTAINS\n  SUBROUTINE foo\n"
-                        "  END\nEND PROGRAM a")
+    obj = Main_Program(
+        get_reader("program a\ni=10\ncontains\nsubroutine foo\n" "end\nend program a")
+    )
+    assert str(obj) == (
+        "PROGRAM a\n  i = 10\n  CONTAINS\n  SUBROUTINE foo\n" "  END\nEND PROGRAM a"
+    )
     # Clear existing symbol tables before next part of this test
     SYMBOL_TABLES.clear()
 
     # specification-part + execution-part + internal-subprogram-part
-    obj = Main_Program(get_reader("program a\ninteger i\ni=10\ncontains\n"
-                                  "subroutine foo\nend\nend program a"))
-    assert str(obj) == ("PROGRAM a\n  INTEGER :: i\n  i = 10\n  CONTAINS\n  "
-                        "SUBROUTINE foo\n  END\nEND PROGRAM a")
+    obj = Main_Program(
+        get_reader(
+            "program a\ninteger i\ni=10\ncontains\n"
+            "subroutine foo\nend\nend program a"
+        )
+    )
+    assert str(obj) == (
+        "PROGRAM a\n  INTEGER :: i\n  i = 10\n  CONTAINS\n  "
+        "SUBROUTINE foo\n  END\nEND PROGRAM a"
+    )
     table = SYMBOL_TABLES.lookup("a")
     assert table.lookup("i")
     assert table.children[0].name == "foo"
 
 
 def test_invalid1(f2003_create):
-    ''' Test that exceptions are raised for invalid code '''
+    """Test that exceptions are raised for invalid code"""
     # no end
     with pytest.raises(NoMatchError) as excinfo:
         _ = Main_Program(get_reader("program a\n"))
@@ -139,31 +153,32 @@ def test_invalid1(f2003_create):
     # name mismatch
     with pytest.raises(FortranSyntaxError) as excinfo:
         _ = Main_Program(get_reader("program a\nend program b"))
-    assert "at line 2\n>>>end program b\nExpecting name 'a'" \
-        in str(excinfo.value)
+    assert "at line 2\n>>>end program b\nExpecting name 'a'" in str(excinfo.value)
     # Check that we have no symbol table
     assert "a" not in SYMBOL_TABLES._symbol_tables
 
 
 def test_invalid2(f2003_create):
-    '''Test that specification-part after execution-part produces an
+    """Test that specification-part after execution-part produces an
     error.
 
-    '''
+    """
     with pytest.raises(NoMatchError) as excinfo:
-        _ = Main_Program(get_reader("program a\ni=10\ninteger i\n"
-                                    "end program a"))
+        _ = Main_Program(get_reader("program a\ni=10\ninteger i\n" "end program a"))
     assert "at line 3\n>>>integer i\n" in str(excinfo.value)
     assert "a" not in SYMBOL_TABLES._symbol_tables
 
 
 def test_invalid3(f2003_create):
-    '''Test that execution-part after internal-subprogram-part produces an
+    """Test that execution-part after internal-subprogram-part produces an
     error.
 
-    '''
+    """
     with pytest.raises(NoMatchError) as excinfo:
-        _ = Main_Program(get_reader("program a\ncontains\nsubroutine foo\n"
-                                    "end\ni=10\nend program a"))
+        _ = Main_Program(
+            get_reader(
+                "program a\ncontains\nsubroutine foo\n" "end\ni=10\nend program a"
+            )
+        )
     assert "at line 5\n>>>i=10\n" in str(excinfo.value)
     assert "a" not in SYMBOL_TABLES._symbol_tables
